@@ -232,7 +232,7 @@ class Visualize:
         )
         fig = self.__upgrade_figure(
             fig,
-            category_order=None,
+            category_order=category_order,
             title=title,
             show_legend=show_legend,
             x_axis_label=x_axis_label,
@@ -242,7 +242,7 @@ class Visualize:
             width=width,
             height=height,
             y_range=y_range,
-            category_order=category_order
+
         )
 
         self.__print(fig, static)
